@@ -46,7 +46,7 @@ char * help_text =
 "    -s <0|1>            Report to syslog (1) or stderr (0, default)\n"
 "    -h                  Show this help\n";
 
-char * progname = "lcdexec";
+char *progname = "lcdexec";
 
 /* Variables set by config */
 #define UNSET_INT -1
@@ -54,10 +54,11 @@ char * progname = "lcdexec";
 char * configfile = NULL;
 char * address = NULL;
 int port = UNSET_INT;
-int foreground_mode = UNSET_INT;
+int foreground = FALSE;
 static int report_level = UNSET_INT;
 static int report_dest = UNSET_INT;
 char *displayname = NULL;
+char *default_shell = NULL;
 
 MenuEntry *main_menu;
 
@@ -65,12 +66,12 @@ MenuEntry *main_menu;
 int sock = -1;
 
 /* Function prototypes */
-int process_command_line(int argc, char **argv);
-int process_configfile(char * configfile);
-int connect_and_setup();
-int process_response(char * str);
-int exec_command(MenuEntry *cmd);
-int main_loop();
+static int process_command_line(int argc, char **argv);
+static int process_configfile(char * configfile);
+static int connect_and_setup(void);
+static int process_response(char *str);
+static int exec_command(MenuEntry *cmd);
+static int main_loop(void);
 
 
 #define CHAIN(e,f) { if (e>=0) { e=(f); }}
@@ -96,7 +97,7 @@ int main(int argc, char **argv)
 	CHAIN(error, connect_and_setup());
 	CHAIN_END(error);
 
-	if(!foreground_mode) {
+	if(foreground != TRUE) {
 		if (daemon(1,1) != 0) {
 			report(RPT_ERR, "Error: daemonize failed");
 		}
@@ -107,7 +108,8 @@ int main(int argc, char **argv)
 	return 0;
 }
 
-int process_command_line(int argc, char **argv)
+
+static int process_command_line(int argc, char **argv)
 {
 	int c;
 	int error = 0;
@@ -137,7 +139,7 @@ int process_command_line(int argc, char **argv)
 			}
 			break;
 		  case 'f':
-			foreground_mode = 1;
+			foreground = TRUE;
 			break;
 		  case 'r':
 			temp_int = strtol(optarg, &end, 0);
@@ -174,7 +176,8 @@ int process_command_line(int argc, char **argv)
 	return error;
 }
 
-int process_configfile(char *configfile)
+
+static int process_configfile(char *configfile)
 {
 	const char *tmp;
 
@@ -199,13 +202,28 @@ int process_configfile(char *configfile)
 				? RPT_DEST_SYSLOG
 				: RPT_DEST_STDERR;
 	}
-	if (foreground_mode == UNSET_INT) {
-		foreground_mode = config_get_bool(progname, "Foreground", 0, 0);
+	if (foreground != TRUE) {
+		foreground = config_get_bool(progname, "Foreground", 0, FALSE);
 	}
 
 	if ((tmp = config_get_string(progname, "DisplayName", 0, NULL)) != NULL)
 		displayname = strdup(tmp);
 
+	/* try to find a shell that understands the -c COMMAND syntax */
+	if ((tmp = config_get_string(progname, "Shell", 0, NULL)) != NULL)
+		default_shell = strdup(tmp);
+	else {
+		/* 1st fallback: SHELL environment variable */
+		report(RPT_WARNING, "Shell not set in configuration, falling back to variable SHELL");
+		default_shell = getenv("SHELL");
+
+		/* 2nd fallback: /bin/sh */
+		if (default_shell == NULL) {
+			report(RPT_WARNING, "variable SHELL not set, falling back to /bin/sh");
+			default_shell = "/bin/sh";
+		}
+	}
+
 	main_menu = menu_read(NULL, "MainMenu");
 #if defined(DEBUG)
 	menu_dump(main_menu);
@@ -220,7 +238,8 @@ int process_configfile(char *configfile)
 	return 0;
 }
 
-int connect_and_setup()
+
+static int connect_and_setup(void)
 {
 	report(RPT_INFO, "Connecting to %s:%d", address, port);
 
@@ -251,7 +270,8 @@ int connect_and_setup()
 	return 0;
 }
 
-int process_response(char *str)
+
+static int process_response(char *str)
 {
 	char *argv[15];
 	int argc;
@@ -308,7 +328,8 @@ int process_response(char *str)
 	return 0;
 }
 
-int exec_command(MenuEntry *cmd)
+
+static int exec_command(MenuEntry *cmd)
 {
 	if ((cmd != NULL)  && (menu_command(cmd) != NULL)) {
 		const char *command = menu_command(cmd);
@@ -316,16 +337,11 @@ int exec_command(MenuEntry *cmd)
 
 		report(RPT_NOTICE, "Executing: %s", command);
 
-		argv[0] = getenv("SHELL");
+		argv[0] = default_shell;
 		argv[1] = "-c";
 		argv[2] = command;
 		argv[3] = NULL;
 
-		if (!argv[0]) {
-			report(RPT_ERR, "SHELL environment variable not set.");
-			return -1;
-		}
-
 		switch (fork()) {
 		  case 0:
 			/* We're the child. Execute the command. */
@@ -344,7 +360,8 @@ int exec_command(MenuEntry *cmd)
 	return -1;
 }
 
-int main_loop ()
+
+static int main_loop(void)
 {
 	int num_bytes;
 	char buf[100];
@@ -365,7 +382,7 @@ int main_loop ()
 			}
 		}
 		else {
-			process_response (buf);
+			process_response(buf);
 		}
 	}
 
