@@ -71,7 +71,7 @@ battery_status(int status)
 // +--------------------+
 //
 int
-battery_screen (int rep, int display, int *flags_ptr)
+battery_screen(int rep, int display, int *flags_ptr)
 {
 	int acstat = 0, battstat = 0, percent = 0;
 	int gauge_wid = lcd_wid - 2;
@@ -79,23 +79,20 @@ battery_screen (int rep, int display, int *flags_ptr)
 	if ((*flags_ptr & INITIALIZED) == 0) {
 		*flags_ptr |= INITIALIZED;
 
-		sock_send_string (sock, "screen_add B\n");
-		sprintf (buffer, "screen_set B -name {APM stats: %s}\n", get_hostname());
-		sock_send_string (sock, buffer);
-		sock_send_string (sock, "widget_add B title title\n");
-		sprintf (buffer, "widget_set B title {LCDPROC %s}\n", version);
-		sock_send_string (sock, buffer);
-		sock_send_string (sock, "widget_add B one string\n");
+		sock_send_string(sock, "screen_add B\n");
+		sock_printf(sock, "screen_set B -name {APM stats: %s}\n", get_hostname());
+		sock_send_string(sock, "widget_add B title title\n");
+		sock_printf(sock, "widget_set B title {LCDPROC %s}\n", version);
+		sock_send_string(sock, "widget_add B one string\n");
 		if (lcd_hgt >= 4) {
-			sock_send_string (sock, "widget_add B two string\n");
-			sock_send_string (sock, "widget_add B three string\n");
-			sock_send_string (sock, "widget_add B gauge hbar\n");
+			sock_send_string(sock, "widget_add B two string\n");
+			sock_send_string(sock, "widget_add B three string\n");
+			sock_send_string(sock, "widget_add B gauge hbar\n");
 
-			sock_send_string (sock, "widget_set B one 1 2 {AC: Unknown}\n");
-			sock_send_string (sock, "widget_set B two 1 3 {Batt: Unknown}\n");
-			sprintf(buffer, "widget_set B three 1 4 {E%*sF}\n", gauge_wid, "");
-			sock_send_string (sock, buffer);
-			sock_send_string (sock, "widget_set B gauge 2 4 0\n");
+			sock_send_string(sock, "widget_set B one 1 2 {AC: Unknown}\n");
+			sock_send_string(sock, "widget_set B two 1 3 {Batt: Unknown}\n");
+			sock_printf(sock, "widget_set B three 1 4 {E%*sF}\n", gauge_wid, "");
+			sock_send_string(sock, "widget_set B gauge 2 4 0\n");
 		}
 	}
 	// Only run once every 16 frames...
@@ -103,36 +100,29 @@ battery_screen (int rep, int display, int *flags_ptr)
 
 	machine_get_battstat(&acstat, &battstat, &percent);
 
-	if (percent >= 0)
-		sprintf(tmp, "%d%%", percent);
-	else
-		sprintf(tmp, "??%%");
-	sprintf(buffer, "widget_set B title {%s: %s: %s}\n",
-			(acstat == LCDP_AC_ON && battstat == LCDP_BATT_ABSENT) ? "AC" : "Batt",
-			tmp, get_hostname());
-	if (display)
-		sock_send_string (sock, buffer);
+	if (display) {
+		char tmp[20];
 
-	if (lcd_hgt >= 4) {				  // 4-line version of the screen
-		sprintf(buffer, "widget_set B one 1 2 {AC: %s}\n", ac_status(acstat));
-		if (display)
-			sock_send_string (sock, buffer);
+		if (percent >= 0)
+			sprintf(tmp, "%d%%", percent);
+		else
+			sprintf(tmp, "??%%");
+		sock_printf(sock, "widget_set B title {%s: %s: %s}\n",
+				(acstat == LCDP_AC_ON && battstat == LCDP_BATT_ABSENT) ? "AC" : "Batt",
+				tmp, get_hostname());
 
-		sprintf(buffer, "widget_set B two 1 3 {Batt: %s}\n", battery_status(battstat));
-		if (display)
-			sock_send_string(sock, buffer);
-
-		if (percent > 0) {
-			sprintf(buffer, "widget_set B gauge 2 4 %d\n", (percent * gauge_wid * lcd_cellwid) / 100);
-			if (display)
-				sock_send_string(sock, buffer);
+		if (lcd_hgt >= 4) {		  // 4-line version of the screen
+			sock_printf(sock, "widget_set B one 1 2 {AC: %s}\n", ac_status(acstat));
+			sock_printf(sock, "widget_set B two 1 3 {Batt: %s}\n", battery_status(battstat));
+			if (percent > 0)
+				sock_printf(sock, "widget_set B gauge 2 4 %d\n",
+						(percent * gauge_wid * lcd_cellwid) / 100);
+		}	
+		else {				  // two-line version of the screen
+			sock_printf(sock, "widget_set B one 1 2 {%sBatt: %s}\n",
+					(acstat == LCDP_AC_ON) ? "AC, " : "",
+					battery_status(battstat));
 		}
-	}	
-	else {						  // two-line version of the screen
-		sprintf(buffer, "widget_set B one 1 2 {%sBatt: %s}\n",
-			(acstat == LCDP_AC_ON) ? "AC, " : "", battery_status(battstat));
-		if (display)
-			sock_send_string(sock, buffer);
 	}
 
 	return 0;
