@@ -49,7 +49,7 @@ static int transfer_screen = 0;  /* by default, transfer screen is not shown */
 
 /* reads and parses configuration file */
 static int
-iface_process_configfile()
+iface_process_configfile(void)
 {
 	const char *unit;
 
@@ -392,12 +392,12 @@ actualize_speed_screen(IfaceInfo *iface, unsigned int interval, int index)
 			format_value_multi_interface(speed, rc_speed, unit_label);
 			format_value_multi_interface(speed1, tr_speed, unit_label);
 			sock_printf(sock, "widget_set I i%1d 1 %1d {%5.5s U:%.4s D:%.4s}\n",
-					index, index+1, iface[index].alias, speed1, speed);
+					index, index+1, iface->alias, speed1, speed);
 		}
 		else { /* Interface is down */
 			get_time_string(speed, iface->last_online);
 			sock_printf(sock, "widget_set I i%1d 1 %1d {%5.5s NA (%s)}\n",
-					index, index+1, iface[index].alias, speed);
+					index, index+1, iface->alias, speed);
 		}
 	}
 } /* actualize_speed_screen() */
@@ -489,12 +489,12 @@ actualize_transfer_screen(IfaceInfo *iface, int index)
 			format_value_multi_interface(transfer, iface->rc_byte, "B");
 			format_value_multi_interface(transfer1, iface->tr_byte, "B");
 			sock_printf(sock, "widget_set NT i%1d 1 %1d {%5.5s U:%.4s D:%.4s}\n",
-					index, index+1, iface[index].alias, transfer1, transfer);
+					index, index+1, iface->alias, transfer1, transfer);
 		}
 		else { /* Interface is down */
 			get_time_string(transfer, iface->last_online);
 			sock_printf(sock, "widget_set NT i%1d 1 %1d {%5.5s NA (%s)}\n",
-					index, index+1, iface[index].alias, transfer);
+					index, index+1, iface->alias, transfer);
 		}
 	}
 } /* actualize_transfer_screen() */
