@@ -47,7 +47,9 @@
 #include <sys/user.h>
 #include <kvm.h>
 #include <errno.h>
-
+#include <sys/socket.h>
+#include <net/if.h>
+#include <net/if_mib.h>
 #include <mach/mach.h>
 
 #include "main.h"
@@ -58,8 +60,6 @@
 #include <CoreFoundation/CoreFoundation.h>
 #include <IOKit/ps/IOPowerSources.h>
 #include <IOKit/ps/IOPSKeys.h>
-//AUTOFRAMEWORK(CoreFoundation)
-//AUTOFRAMEWORK(IOKit)
 
 static int pageshift;
 #define pagetok(size) ((size) << pageshift)
@@ -67,10 +67,11 @@ static int swapmode(int *rettotal, int *retfree);
 
 static mach_port_t lcdproc_port;
 
-int machine_init()
+
+int machine_init(void)
 {
 	/* get the page size with "getpagesize" and calculate pageshift from it */
-	int pagesize = 0;
+	unsigned int pagesize = 0;
 	pageshift = 0;
 
 	lcdproc_port = mach_host_self();
@@ -88,7 +89,7 @@ int machine_init()
 	return(TRUE);
 }
 
-int machine_close()
+int machine_close(void)
 {
 	return(TRUE);
 }
@@ -150,7 +151,8 @@ int machine_get_battstat(int *acstat, int *battflag, int *percent)
 				*percent = (int)((double)curCapacity/(double)maxCapacity * 100);
 
 				/*	There is a way to check this through the IOKit,
-					but I am not sure what gets for kIOPSLowWarnLevelKey and kIOPSDeadWarnLevelKey, and this is easier.
+					but I am not sure what gets returned for kIOPSLowWarnLevelKey and kIOPSDeadWarnLevelKey, 
+					and this is easier.
 				*/
 				if (*battflag == LCDP_BATT_UNKNOWN) {
 					if (*percent > 50)
@@ -199,7 +201,7 @@ int machine_get_fs(mounts_type fs[], int *cnt)
 		{
 			snprintf(fs[statcnt].dev,    255, "%s", pp->f_mntfromname);
 			snprintf(fs[statcnt].mpoint, 255, "%s", pp->f_mntonname);
-			snprintf(fs[statcnt].type,   255, "%s", pp->f_fstypename);
+			snprintf(fs[statcnt].type,    63, "%s", pp->f_fstypename);
 
 			fs[statcnt].blocks = pp->f_blocks;
 			if (fs[statcnt].blocks > 0)
@@ -261,12 +263,12 @@ int machine_get_load(load_type *curr_load)
 
 int machine_get_loadavg(double *load)
 {
-	double loadavg[1];
+	double loadavg[LOADAVG_NSTATS];
 
-	if (getloadavg(loadavg, 1) == -1)
+	if (getloadavg(loadavg, LOADAVG_NSTATS) <= LOADAVG_1MIN)
 		return(FALSE);
 
-	*load = loadavg[0];
+	*load = loadavg[LOADAVG_1MIN];
 
 	return(TRUE);
 }
@@ -307,39 +309,82 @@ int machine_get_meminfo(meminfo_type *result)
 
 int machine_get_procs(LinkedList *procs)
 {
-	#warning machine_get_procs not implemented
-	return(FALSE);
-	/* FIX ME */
-	/* This needs to be finished. */
-	procinfo_type	*p;
+	struct kinfo_proc *kprocs;
+	
+	procinfo_type *p;
+	int nproc, i;
+	int mib[] = { CTL_KERN, KERN_PROC, KERN_PROC_ALL, 0 };
 
-	processor_set_t *psets, pset;
-	task_t          *tasks;
+	size_t size = 0;
 
-	unsigned int nproc, i;
-
-	if (host_processor_sets(lcdproc_port, &psets, &nproc))
+	/* Call sysctl with a NULL buffer as a dry run. */ 
+	if ( sysctl(mib, 4, NULL, &size, NULL, 0 ) < 0)
 	{
-		perror("host_processor_sets");
-		return(FALSE);
+		perror("Failure calling sysctl");
+		return FALSE;
+	}
+	/* Allocate a buffer based on previous results of sysctl. */ 
+	kprocs = (struct kinfo_proc *)alloca(size);
+	if (kprocs == NULL)
+	{
+		perror("mem_alloca");
+		return FALSE;
+	}
+	/* Call sysctl again with the new buffer. */
+	if ( sysctl(mib, 4, kprocs, &size, NULL, 0 ) < 0)
+	{
+		perror("Failure calling sysctl");
+		return FALSE;
 	}
 
-	for (i = 0; i < nproc; i++)
+	nproc = size / sizeof(struct kinfo_proc);		
+
+	for (i = 0; i < nproc; i++, kprocs++)
 	{
-		if (host_processor_set_priv(lcdproc_port, psets[i], &pset))
-		{
-			perror("host_processor_set_priv");
-			return(FALSE);
-		}
+		mach_port_t task;
+		unsigned int status = kprocs->kp_proc.p_stat;
+
+		if (status == SIDL ||status == SZOMB)
+			continue;
 
 		p = malloc(sizeof(procinfo_type));
 		if (!p)
 		{
-			perror("mem_top_malloc");
-			return(FALSE);
+			perror("mem_malloc");
+			continue;
 		}
+		strncpy(p->name, kprocs->kp_proc.p_comm, 15);
+		p->name[15] = '\0';
 
+		p->number = kprocs->kp_proc.p_pid;
+
+		LL_Push(procs, (void *)p);
+
+		/* Normal user can't get tasks for processes owned by root. */
+		if (kprocs->kp_eproc.e_pcred.p_ruid == 0)
+			continue;
+
+		/* Get the memory data for each pid from Mach. */
+		if (task_for_pid(mach_task_self(), kprocs->kp_proc.p_pid, &task) == KERN_SUCCESS)
+		{
+			task_basic_info_data_t info;
+			mach_msg_type_number_t count = TASK_BASIC_INFO_COUNT;
+
+			if (task_info(task, TASK_BASIC_INFO, (task_info_t)&info, &count) == KERN_SUCCESS) {
+				p->totl = (unsigned long)(/*info.virtual_size*/ info.resident_size / 1024);
+			}
+		} else {
+			/*	This error pops up very often because of Mac OS X security fixes.
+				It might pop up all of the time on an intel Mac.
+				Basically, we cannot get many tasks unless we are root. 
+			perror("task_for_pid");
+			printf("process: %s, owner:%d\n", kprocs->kp_proc.p_comm, kprocs->kp_eproc.e_pcred.p_ruid); */
+			p->totl = 0;
+		}
 	}
+
+	kprocs -= i;
+
 	return(TRUE);
 }
 
@@ -350,8 +395,7 @@ int machine_get_smpload(load_type *result, int *numcpus)
 	load_type curr_load;
 
 	size = sizeof(int);
-	if (sysctlbyname("hw.ncpu", &num, &size, NULL, 0) < 0)
-	{
+	if (sysctlbyname("hw.ncpu", &num, &size, NULL, 0) < 0) {
 		perror("sysctl hw.ncpu");
 		return(FALSE);
 	}
@@ -359,11 +403,15 @@ int machine_get_smpload(load_type *result, int *numcpus)
 	if (machine_get_load(&curr_load) == FALSE)
 		return(FALSE);
 
+	if (numcpus == NULL)
+		return(FALSE);
+
+	/* restrict #CPUs to max. *numcpus */
+	num = (*numcpus >= num) ? num : *numcpus;
 	*numcpus = num;
-	num = num > 8 ? 8 : num;
+
 	/* Don't know how to get per-cpu-load values */
-	for (i = 0; i < num; i++)
-	{
+	for (i = 0; i < num; i++) {
 		result[i] = curr_load;
 	}
 
@@ -431,8 +479,60 @@ static int swapmode(int *rettotal, int *retfree)
 /* Get network statistics */
 int machine_get_iface_stats (IfaceInfo *interface)
 {
-	/* Implementation missing */
-	return 0;
-}
+	static int      first_time = 1;	/* is it first time we call this function? */
+	int             rows;
+	int             name[6] = {CTL_NET, PF_LINK, NETLINK_GENERIC, IFMIB_SYSTEM, IFMIB_IFCOUNT};
+	size_t          len;
+	struct ifmibdata ifmd; /* ifmibdata contains the network statistics */
+	
+	len = sizeof(rows);
+	/* get number of interfaces */
+	//if (sysctlbyname("net.link.generic.system.ifcount", &rows, &len, NULL, 0) == 0) {
+	if (sysctl(name, 5, &rows, &len, 0, 0) == 0) {
+		interface->status = down; /* set status down by default */
+		
+		name[3] = IFMIB_IFDATA;
+		name[4] = 0;
+		name[5] = IFDATA_GENERAL;
+		
+		len = sizeof(ifmd);
+		/* walk through all interfaces in the ifmib table from last to first */
+		for ( ; rows > 0; rows--) {
+			name[4] = rows; /* set the interface index */
+			/* retrive the ifmibdata for the current index */
+			if (sysctl(name, 6, &ifmd, &len, NULL, 0) == -1) {
+				perror("read sysctl");
+				break;
+			}
+			/* check if its interface name matches */
+			if (strcmp(ifmd.ifmd_name, interface->name) == 0) {
+				interface->last_online = time(NULL);	/* save actual time */
+				
+				if ((ifmd.ifmd_flags & IFF_UP) == IFF_UP)
+					interface->status = up;	/* is up */
+
+				interface->rc_byte = ifmd.ifmd_data.ifi_ibytes;
+				interface->tr_byte = ifmd.ifmd_data.ifi_obytes;
+				interface->rc_pkt = ifmd.ifmd_data.ifi_ipackets;
+				interface->tr_pkt = ifmd.ifmd_data.ifi_opackets;
+
+				if (first_time) {
+					interface->rc_byte_old = interface->rc_byte;
+					interface->tr_byte_old = interface->tr_byte;
+					interface->rc_pkt_old = interface->rc_pkt;
+					interface->tr_pkt_old = interface->tr_pkt;
+					first_time = 0;	/* now it isn't first time */
+				}
+				return 1;
+			}
+		}
+		/* if we are here there is no interface with the given name */
+		return 0;
+	} else {
+		perror("read sysctl IFMIB_IFCOUNT");
+		return 0;
+	}
+} /* get_iface_stats() */
+
 
 #endif /* __APPLE__ */
