@@ -61,7 +61,8 @@ static int pageshift;
 #define pagetok(size) ((size) << pageshift)
 static int swapmode(int *retavail, int *retfree);
 
-int machine_init()
+
+int machine_init(void)
 {
 	/* get the page size with "getpagesize" and calculate pageshift from it */
 	int pagesize = getpagesize();
@@ -78,7 +79,7 @@ int machine_init()
 	return(TRUE);
 }
 
-int machine_close()
+int machine_close(void)
 {
 	return(TRUE);
 }
@@ -172,7 +173,7 @@ int machine_get_fs(mounts_type fs[], int *cnt)
 		{
 			snprintf(fs[statcnt].dev,    255, "%s", pp->f_mntfromname);
 			snprintf(fs[statcnt].mpoint, 255, "%s", pp->f_mntonname);
-			snprintf(fs[statcnt].type,   255, "%s", pp->f_fstypename);
+			snprintf(fs[statcnt].type,    63, "%s", pp->f_fstypename);
 
 			fs[statcnt].blocks = pp->f_blocks;
 			if (fs[statcnt].blocks > 0)
@@ -232,12 +233,12 @@ int machine_get_load(load_type *curr_load)
 
 int machine_get_loadavg(double *load)
 {
-	double loadavg[1];
+	double loadavg[LOADAVG_NSTATS];
 
-	if (getloadavg(loadavg, 1) == -1)
+	if (getloadavg(loadavg, LOADAVG_NSTATS) <= LOADAVG_1MIN)
 		return(FALSE);
 
-	*load = loadavg[0];
+	*load = loadavg[LOADAVG_1MIN];
 
 	return(TRUE);
 }
@@ -343,8 +344,7 @@ int machine_get_smpload(load_type *result, int *numcpus)
 	load_type curr_load;
 
 	size = sizeof(int);
-	if (sysctlbyname("hw.ncpu", &num, &size, NULL, 0) < 0)
-	{
+	if (sysctlbyname("hw.ncpu", &num, &size, NULL, 0) < 0) {
 		perror("sysctl hw.ncpu");
 		return(FALSE);
 	}
@@ -352,11 +352,15 @@ int machine_get_smpload(load_type *result, int *numcpus)
 	if (machine_get_load(&curr_load) == FALSE)
 		return(FALSE);
 
+	if (numcpus == NULL)
+		return(FALSE);
+
+	/* restrict #CPUs to max. *numcpus */
+	num = (*numcpus >= num) ? num : *numcpus;
 	*numcpus = num;
-	num = num > 8 ? 8 : num;
+
 	/* Don't know how to get per-cpu-load values */
-	for (i = 0; i < num; i++)
-	{
+	for (i = 0; i < num; i++) {
 		result[i] = curr_load;
 	}
 
