@@ -189,8 +189,8 @@ menu_add_item_func (Client * c, int argc, char **argv)
 		item = menuitem_create_ip (item_id, menu_commands_handler, text, c,
 				0, "192.168.1.245");
 		break;
- 	 default:
- 	   assert(!"unexpected menuitem type");
+	 default:
+	   assert(!"unexpected menuitem type");
 	}
 	menu_add_item (menu, item);
 	menuscreen_inform_item_modified (menu);
@@ -213,7 +213,7 @@ menu_add_item_func (Client * c, int argc, char **argv)
 			/* skip "text" */
 			if (i == 4 && argv[4][0] != '-')
 				continue;
-			
+
 			argv_set[j++] = argv[i];
 		}
 		menu_set_item_func(c, j, argv_set);
@@ -242,7 +242,7 @@ menu_del_item_func (Client * c, int argc, char **argv)
 	if (!c->ack)
 		return 1;
 
-	if ((argc < 3 )) {
+	if (argc != 3 ) {
 		sock_send_error(c->sock, "Usage: menu_del_item <menuid> <itemid>\n");
 		return 0;
 	}
@@ -451,7 +451,7 @@ menu_set_item_func (Client * c, int argc, char **argv)
 	if (!c->ack)
 		return 1;
 
-	if ((argc < 4 )) {
+	if (argc < 4 ) {
 		sock_send_error(c->sock, "Usage: menu_set_item <menuid> <itemid> {<option>}+\n");
 		return 0;
 	}
@@ -670,7 +670,7 @@ menu_set_item_func (Client * c, int argc, char **argv)
 
 				new_buf = malloc(item->data.ip.maxlength + 1 );
 				strncpy( new_buf, item->data.ip.value, item->data.ip.maxlength);
-				
+
 				new_buf[item->data.ip.maxlength] = '\0'; /* terminate */
 				free( item->data.ip.value );
 				item->data.ip.value = new_buf;
@@ -712,7 +712,7 @@ menu_set_item_func (Client * c, int argc, char **argv)
  * to go to a menu of another client (or the server menus). Same
  * restriction applies to the optional predecessor_id
  *
- * usage: menu_goto <id> [<predecessor_id>]
+ * Usage: menu_goto <id> [<predecessor_id>]
  */
 int
 menu_goto_func (Client * c, int argc, char **argv)
@@ -726,7 +726,7 @@ menu_goto_func (Client * c, int argc, char **argv)
 	if (!c->ack)
 		return 1;
 
-	if ((argc < 2 )) {
+	if ((argc < 2 ) || (argc > 3)) {
 		sock_send_error(c->sock, "Usage: menu_goto <menuid> [<predecessor_id>]\n");
 		return 0;
 	}
@@ -746,7 +746,7 @@ menu_goto_func (Client * c, int argc, char **argv)
 		return 0;
 	}
 
-	if ((argc > 2 ))
+	if (argc > 2 )
 		set_predecessor(menu, argv[2], c);
 
 	menuscreen_goto (menu);
@@ -836,7 +836,7 @@ int set_successor(MenuItem *item, char *itemid, Client *c)
 /***************************************************************
  * Requests the menu system to set the entry point into the menu system. 
  *
- * usage: menu_set_main <id>
+ * Usage: menu_set_main <id>
  */
 int
 menu_set_main_func (Client * c, int argc, char **argv)
@@ -850,7 +850,7 @@ menu_set_main_func (Client * c, int argc, char **argv)
 	if (!c->ack)
 		return 1;
 
-	if ((argc < 2 )) {
+	if (argc != 2 ) {
 		sock_send_error(c->sock, "Usage: menu_set_main <menuid>\n");
 		return 0;
 	}
@@ -931,11 +931,11 @@ MenuEventFunc (menu_commands_handler)
 		}
 	}
 	else if (event == MENUEVENT_ENTER
- 		|| event == MENUEVENT_LEAVE)
+		|| event == MENUEVENT_LEAVE)
         {
- 	 snprintf (buf, sizeof(buf)-1, "menuevent %s %.40s\n",
- 		   menuitem_eventtype_to_eventtypename(event),
- 		   item->id);
+	 snprintf (buf, sizeof(buf)-1, "menuevent %s %.40s\n",
+		   menuitem_eventtype_to_eventtypename(event),
+		   item->id);
 	}
 	else {
 		snprintf (buf, sizeof(buf)-1, "menuevent %s %.40s\n",
@@ -949,7 +949,7 @@ MenuEventFunc (menu_commands_handler)
 	c = menuitem_get_client(item);
 	if( !c ) {
 		report( RPT_ERR, "%s: Could not find client of item \"%s\"",
- 		       __FUNCTION__, item->id );
+		       __FUNCTION__, item->id );
 		return -1;
 	}
 
