@@ -129,7 +129,8 @@ static void CFontz633_hardware_clear (Driver *drvthis);
 /**
  * Initialize the driver.
  * \param drvthis  Pointer to driver structure.
- * \return  Information of success (0) or failure (non-0).
+ * \retval 0   Success.
+ * \retval <0  Error.
  */
 MODULE_EXPORT int
 CFontz633_init (Driver *drvthis)
@@ -784,14 +785,14 @@ int do_init = 0;
 	}
 
 	// Lib_adv_bignum does everything needed to show the bignumbers.
-	lib_adv_bignum(drvthis, x, num, do_init, NUM_CCs);
+	lib_adv_bignum(drvthis, x, num, 0, do_init);
 }
 
 
 /**
- * Get number of custom chars available.
+ * Get total number of custom characters available.
  * \param drvthis  Pointer to driver structure.
- * \returns  Number of custom characters (always NUM_CCs).
+ * \return  Number of custom characters (always NUM_CCs).
  */
 MODULE_EXPORT int
 CFontz633_get_free_chars (Driver *drvthis)
@@ -1057,7 +1058,7 @@ CFontz633_hardware_clear (Driver *drvthis)
  * \param string   String that gets written.
  */
 MODULE_EXPORT void
-CFontz633_string (Driver *drvthis, int x, int y, char string[])
+CFontz633_string (Driver *drvthis, int x, int y, const char string[])
 {
 	PrivateData *p = drvthis->private_data;
 	int i;
