@@ -21,10 +21,10 @@
   in this file was either written by David Glaude for LCDproc or
   identical to the GPL'ed code or so close to it that the differences
   are negligible.
-    
+
   For detailed information about the code analysis, please
   contact the LCDproc maintainer, Peter Marschall <peter@adpm.de>
-    
+
   This file is hereby released under the terms below:
 
     This program is free software; you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
- 
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
+
  */
 
 #include <unistd.h>
@@ -64,6 +64,12 @@
 #define GIVE_UP 2
 
 
+/* define CFONTZ633_WRITE_DELAY to use select when waiting for packet acknowledgement */
+#if !defined(CFONTZ633_WRITE_DELAY)
+# define CFONTZ633_WRITE_DELAY	250
+#endif
+
+
 /* static local functions */
 static void send_packet(int fd, COMMAND_PACKET *out, COMMAND_PACKET *in);
 static int  get_crc(unsigned char *buf, int len, int seed);
@@ -95,13 +101,13 @@ void EmptyKeyRing(KeyRing *kr)
 int AddKeyToKeyRing(KeyRing *kr, unsigned char key)
 {
 	if (((kr->head + 1) % KEYRINGSIZE) != (kr->tail % KEYRINGSIZE)) {
- 		/* fprintf(stderr, "We add key: %d\n", key); */
+		/* fprintf(stderr, "We add key: %d\n", key); */
 
 	        kr->contents[kr->head % KEYRINGSIZE] = key;
   		kr->head = (kr->head + 1) % KEYRINGSIZE;
 		return 1;
 	}
-	
+
 	/* KeyRing overflow: do not accept extra key */
 	return 0;
 }
@@ -173,14 +179,18 @@ void send_zerobyte_message(int fd, unsigned char msg)
 static void
 send_packet(int fd, COMMAND_PACKET *out, COMMAND_PACKET *in)
 {
+	unsigned char CRC[2];
+
 	write(fd, &out->command, 1);
 	write(fd, &out->data_length, 1);
 	if (out->data_length > 0)
 		write(fd, out->data, out->data_length);
 
-	/* calculate & send the CRC */
-	out->crc.as_word = get_crc((unsigned char *) out, out->data_length + 2, 0xFFFF);
-	write(fd, out->crc.as_bytes, 2);
+	/* calculate & send the CRC: convert to bytes manually to avoid endianess issues */
+	out->crc = get_crc((unsigned char *) out, out->data_length + 2, 0xFFFF);
+	CRC[0] = out->crc & 0xFF;
+	CRC[1] = (out->crc >> 8) & 0xFF;
+	write(fd, CRC, 2);
 
 	/**** TEST STUFF ****/
 	// print_packet(out);
@@ -271,7 +281,7 @@ void SyncReceiveBuffer(ReceiveBuffer *rb, int fd, unsigned int number)
 {
 	unsigned char buffer[MAX_DATA_LENGTH];
 	int BytesRead;
-	
+
 #if defined(HAVE_SELECT) && defined(CFONTZ633_WRITE_DELAY) && (CFONTZ633_WRITE_DELAY > 0)
 	fd_set rfds;
 	struct timeval timeout;
@@ -332,7 +342,7 @@ int BytesAvail(ReceiveBuffer *rb)
 unsigned char GetByte(ReceiveBuffer *rb)
 {
 	unsigned char return_byte = '\0';
-  
+
 	/* wrap read pointer to the receive buffer */
 	rb->tail %= RECEIVEBUFFERSIZE;
 
@@ -353,7 +363,7 @@ unsigned char GetByte(ReceiveBuffer *rb)
 int PeekBytesAvail(ReceiveBuffer *rb)
 {
 	int avail_bytes = rb->head - rb->peek;
-	
+
 	if (avail_bytes < 0)
 		avail_bytes += RECEIVEBUFFERSIZE;
 
@@ -368,7 +378,7 @@ void SyncPeekPointer(ReceiveBuffer *rb)
 }
 
 
-/** accept ppeked data by syncing the read pointer to the peek pointer */
+/** accept peeked data by syncing the read pointer to the peek pointer */
 void AcceptPeekedData(ReceiveBuffer *rb)
 {
 	rb->tail = rb->peek;
@@ -410,7 +420,7 @@ test_packet(int fd, unsigned char response, COMMAND_PACKET *in)
 	/* wait for answer packet but forever (LCDs should answer within max. 250ms) */
 	for (loop = 250000/CFONTZ633_WRITE_DELAY; !response_received && loop > 0; loop--) {
 		int is_msg = check_for_packet(fd, in, MAX_DATA_LENGTH);
-		
+
 		while (is_msg != GIVE_UP) {
 			if (is_msg == GOOD_MSG) {
 				/* key activity ? */
@@ -431,7 +441,7 @@ test_packet(int fd, unsigned char response, COMMAND_PACKET *in)
 			if (in->command == 0x80)
 				AddKeyToKeyRing(&keyring, in->data[0]);
 		}
-	
+
 		is_msg = check_for_packet(fd, in, MAX_DATA_LENGTH);
 	}
 
@@ -487,10 +497,10 @@ check_for_packet(int fd, COMMAND_PACKET *in, unsigned char expected_length)
 		/* fprintf(stderr, "###: Unknown command.\n"); */
 		return(TRY_AGAIN);
 	}
-	
+
   	/* There is a valid command byte. Get the data_length. */
 	in->data_length = PeekByte(&receivebuffer);
-	
+
   	/* The data length must be within reason. */
   	if (MAX_DATA_LENGTH < in->data_length) {
 		//Throw out one byte of garbage. Next pass through should re-sync.
@@ -512,17 +522,16 @@ check_for_packet(int fd, COMMAND_PACKET *in, unsigned char expected_length)
 	for (i = 0; i < in->data_length; i++)
 		in->data[i] = PeekByte(&receivebuffer);
 
-	//Now move over the CRC.
-	in->crc.as_bytes[0] = PeekByte(&receivebuffer);
-	in->crc.as_bytes[1] = PeekByte(&receivebuffer);
-	//Now check the CRC.
+	//Now move over the CRC: convert CRC bytes to CRC manually to avoid endianness issues
+	in->crc = PeekByte(&receivebuffer);
+	in->crc |= PeekByte(&receivebuffer) << 8;
 
 	//Compute the expected CheckSum
 	testcrc = get_crc((unsigned char *) in, in->data_length+2, 0xFFFF);
 
-	if (in->crc.as_word == testcrc) {
-		//This is a good packet. I'll be horn swaggled. Remove the packet
-		//from the serial buffer.
+	//Now check the CRC.
+	if (in->crc == testcrc) {
+		//This is a good packet. Remove the packet from the serial buffer.
 		AcceptPeekedData(&receivebuffer);
 		//Let our caller know that incoming_command has good stuff in it.
 		/* print_packet(&outgoing_response); */
@@ -535,7 +544,7 @@ check_for_packet(int fd, COMMAND_PACKET *in, unsigned char expected_length)
 	*/
 	GetByte(&receivebuffer);
 	/* fprintf(stderr, "###: Wrong CheckSum. computed/real %04x:%04x \n",
-  		   testcrc, incoming_command.crc.as_word); */
+  		   testcrc, incoming_command.crc); */
 	return(TRY_AGAIN);
 }
 
@@ -559,7 +568,7 @@ print_packet(COMMAND_PACKET *packet)
 	//There is enough data to make a packet. Transfer over the data.
 	for (i = 0; i < packet->data_length; i++)
 		fprintf(stderr, " %02x", packet->data[i]);
-  
-	fprintf(stderr, " ] %02x %02x .\n", packet->crc.as_bytes[0], packet->crc.as_bytes[1]);
+
+	fprintf(stderr, " ] %02x %02x .\n", packet->crc & 0xFF, (packet->crc >> 8) & 0xFF);
 }
 
