@@ -122,12 +122,12 @@ MODULE_EXPORT char *symbol_prefix = "IOWarrior_";
 MODULE_EXPORT int  IOWarrior_init(Driver *drvthis);
 MODULE_EXPORT void IOWarrior_close(Driver *drvthis);
 MODULE_EXPORT int  IOWarrior_width(Driver *drvthis);
+MODULE_EXPORT int  IOWarrior_height(Driver *drvthis);
 MODULE_EXPORT int  IOWarrior_cellheight(Driver *drvthis);
 MODULE_EXPORT int  IOWarrior_cellwidth(Driver *drvthis);
-MODULE_EXPORT int  IOWarrior_height(Driver *drvthis);
 MODULE_EXPORT void IOWarrior_clear(Driver *drvthis);
 MODULE_EXPORT void IOWarrior_chr(Driver *drvthis, int x, int y, char c);
-MODULE_EXPORT void IOWarrior_string(Driver *drvthis, int x, int y, char string[]);
+MODULE_EXPORT void IOWarrior_string(Driver *drvthis, int x, int y, const char string[]);
 MODULE_EXPORT void IOWarrior_flush(Driver *drvthis);
 MODULE_EXPORT void IOWarrior_backlight(Driver *drvthis, int on);
 MODULE_EXPORT void IOWarrior_vbar(Driver *drvthis, int x, int y, int len, int promille, int options);
