@@ -571,7 +571,7 @@ MD8800_clear (Driver *drvthis)
 // upper-left is (1,1), and the lower right should be (20,4).
 //
 MODULE_EXPORT void
-MD8800_string (Driver *drvthis, int x, int y, char string[])
+MD8800_string (Driver *drvthis, int x, int y, const char string[])
 {
 	PrivateData *p = drvthis->private_data;
 	int i;
