@@ -688,7 +688,7 @@ NoritakeVFD_clear (Driver *drvthis)
 // upper-left is (1,1), and the lower right should be (20,4).
 //
 MODULE_EXPORT void
-NoritakeVFD_string (Driver *drvthis, int x, int y, char string[])
+NoritakeVFD_string (Driver *drvthis, int x, int y, const char string[])
 {
 	PrivateData *p = drvthis->private_data;
 	int i;
