@@ -101,7 +101,7 @@ joy_init (Driver *drvthis)
 	report(RPT_INFO, "%s: using Device %s", drvthis->name, p->device);
 
 	/* End of config file parsing (1st part) */
-	
+
 	if ((p->fd = open(p->device, O_RDONLY)) < 0) {
 		report(RPT_ERR, "%s: open(%s) failed (%s)", 
 				drvthis->name, p->device, strerror(errno));
@@ -133,7 +133,7 @@ joy_init (Driver *drvthis)
 
 	for (i = 0; i < p->axes; i++) {
 		char mapkey[50];
-		char *mapval;
+		const char *mapval;
 
 		snprintf(mapkey, sizeof(mapkey), "Map_Axis%dneg", i+1);
 		mapval = drvthis->config_get_string(drvthis->name, mapkey, 0, NULL);
@@ -151,10 +151,10 @@ joy_init (Driver *drvthis)
 					drvthis->name, i+1, p->axismap[2*i + 1]);
 		}	
 	}
-	
+
 	for (i = 0; i < p->buttons; i++) {
 		char mapkey[50];
-		char *mapval;
+		const char *mapval;
 
 		snprintf(mapkey, sizeof(mapkey), "Map_Button%d", i+1);
 		mapval = drvthis->config_get_string(drvthis->name, mapkey, 0, NULL);
@@ -164,9 +164,9 @@ joy_init (Driver *drvthis)
 					drvthis->name, i+1, p->buttonmap[i]);
 		}	
 	}
-	
+
 	/* End of config file parsing (2nd part) */
-	
+
 	report(RPT_DEBUG, "%s: init() done", drvthis->name);
 
 	return 0;
@@ -177,7 +177,7 @@ MODULE_EXPORT void
 joy_close (Driver *drvthis)
 {
 	PrivateData *p = drvthis->private_data;
-	
+
 	if (p != NULL) {
 		if (p->fd >= 0)
 			close(p->fd);
@@ -221,7 +221,7 @@ joy_get_key (Driver *drvthis)
 			return p->buttonmap[js.number];
 		case JS_EVENT_AXIS:
 			/* ignore noise */
-			if ((js.value > -20000) || (js.value < 20000)
+			if (((js.value > -20000) && (js.value < 20000))
 			    || (js.number >= 2 * p->axes))
 				return NULL;
 			return p->axismap[js.number];
