@@ -339,7 +339,7 @@ lcdm001_chr (Driver *drvthis, int x, int y, char c)
 // upper-left is (1,1), and the lower right should be (20,4).
 //
 MODULE_EXPORT void
-lcdm001_string (Driver *drvthis, int x, int y, char *string)
+lcdm001_string (Driver *drvthis, int x, int y, const char string[])
 {
 	PrivateData *p = drvthis->private_data;
 	int i;
