@@ -5,7 +5,7 @@
 
  Copyright (C) 2005 Silvan Marco Fin <silvan@kernelconcepts.de>
  Copyright (C) 2006 coresystems GmbH <info@coresystems.de>
- 
+
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
@@ -18,7 +18,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
 
  */
 
@@ -34,9 +34,14 @@
  *  2006-02-20 Stefan Reinauer <stepan@coresystems.de>
  *   - add support for onboard LEDs via "output" command
  *  2006-04-12 Stefan Reinauer <stepan@coresystems.de>
- *   - add support for user defined characters (set_char/get_free_chars)
+ *   - add support for user-defined characters (set_char/get_free_chars)
  *   - add support for vbars/hbars, get_info, reorganize pyramid_init()
  *   - fixed a timing bug and implemented escaping in (real_)send_tele()
+ *  2006-04-18 Stefan Reinauer <stepan@coresystems.de>
+ *   - support combined key events
+ *   - add more custom characters
+ *   - fix german umlauts
+ *   - fix cursor handling
  */
 
 #include <sys/types.h>
@@ -180,7 +185,7 @@ real_send_tele(PrivateData *p, char *buffer, int len)
      * characters below 0x20.
      * ie. 0x8 --> <ESC> 0x28
      */
-    
+
     while (len--) {
         if (buffer[i]<0x20) {
             buffer2[j++]=0x1b;
@@ -191,7 +196,7 @@ real_send_tele(PrivateData *p, char *buffer, int len)
     }
     buffer2[j++]=3; // emit <ETX> 
     len=j;	    // new package length
-    
+
     /* calculate <BCC> over all bytes */
     for (i=0; i<len; i++)
         cc ^= buffer2[i];
@@ -203,7 +208,7 @@ real_send_tele(PrivateData *p, char *buffer, int len)
 
     /* Take a little nap. This works as a pacemaker */
     usleep(50);
-    
+
     /*debug(RPT_DEBUG, "%s: sent %s", __FUNCTION__, buffer);*/
 
     return 0;
@@ -297,7 +302,7 @@ pyramid_init (Driver *drvthis, char *args)
     PrivateData *p;
 
     /* get memory for private data */
-    
+
     p = (PrivateData *) malloc(sizeof(PrivateData));
     if ((p == NULL) || (drvthis->store_private_ptr(drvthis, p) < 0))
     {
@@ -312,14 +317,14 @@ pyramid_init (Driver *drvthis, char *args)
     p->cellwidth=CELLWIDTH;
     p->cellheight=CELLHEIGHT;
     p->custom = normal;
-    
+
     strcpy(p->last_key_pressed, NOKEY);
     p->last_key_time = timestamp(p);
     p->last_buf_time = timestamp(p);
 
     p->timeout.tv_sec = 0;
     p->timeout.tv_usec = MICROTIMEOUT;
-    
+
     strcpy(p->framebuffer, "D                                ");
     p->FB_modified = 1;
 
@@ -333,7 +338,7 @@ pyramid_init (Driver *drvthis, char *args)
     report(RPT_INFO, "%s: using Device %s", drvthis->name, p->device);
 
     /* Initialize connection to the LCD  */
-    
+
     /* open and initialize serial device */
     p->FD = open(p->device, O_RDWR);
 
@@ -341,16 +346,16 @@ pyramid_init (Driver *drvthis, char *args)
         report(RPT_ERR, "%s: open(%s) failed: %s", drvthis->name, p->device, strerror(errno));
         return -1;
     }
-    
+
     if (initTTY(drvthis, p->FD) != 0)
         return -1;
-    
+
     /* Acknowledge all telegramms, the device may yet be sending.
      * (Reset doesn't clear telegramms, darn protocol ... )
      */
 
     tcflush(p->FD, TCIFLUSH); /* clear everything */
-    
+
     while (1) {
         i = read_tele(p, buffer);
         if (i == True)
@@ -381,6 +386,10 @@ pyramid_init (Driver *drvthis, char *args)
     	set_leds(p);
 	usleep(10000);
     }
+    for (i = 0; i < 7; i++) {
+    	p->led[i] = 0;
+    }
+    set_leds(p);
 
     report(RPT_DEBUG, "%s: init() done", drvthis->name);
 
@@ -427,20 +436,39 @@ pyramid_clear (Driver *drvthis)
 MODULE_EXPORT void 
 pyramid_flush (Driver *drvthis)
 {
-    static char mesg[16];
+    static char mesg[33];
     PrivateData *p = (PrivateData *) drvthis->private_data;
     unsigned long long current_time=timestamp(p);
+    int i;
 
     if ((p->FB_modified==True) && (current_time>(p->last_buf_time+40000)))
     {
+	memcpy(mesg, p->framebuffer, 33);
+
+	// we got the japanese HD44780U, so convert the german umlauts and
+	// other stuff
+	for (i=1; i<33; i++) {
+		switch ((unsigned char)mesg[i]) {
+		// assume input is iso_8859-1
+		case 0xe4: mesg[i]=0xe1; break; // 
+		case 0xf6: mesg[i]=0xef; break; // 
+		case 0xfc: mesg[i]=0xf5; break; // 
+		// This makes the display show nothing
+		// though it is correct according the HD44780U DS
+		//case 0xdf: mesg[i]=0xe2; break; // 
+		case 0xb7: mesg[i]=0xa5; break; // 
+		case 0xb0: mesg[i]=0xdf; break; // 
+		}
+	}
+
         send_tele(p, "C0101");
-        real_send_tele(p, p->framebuffer, 33); /* We do not wait for the ACK here*/
+        real_send_tele(p, mesg, 33); /* We do not wait for the ACK here*/
         p->FB_modified=False;
         p->last_buf_time=current_time;
         sprintf(mesg, "C%02d%02d", p->C_x, p->C_y);
-        send_tele(p, mesg);
+        real_send_tele(p, mesg,5);
         sprintf(mesg, "M%d", p->C_state);
-        send_tele(p, mesg);
+        real_send_tele(p, mesg,2);
     }
 }
 
@@ -477,15 +505,15 @@ MODULE_EXPORT void pyramid_set_char (Driver *drvthis, int n, char *dat)
 {
 	char tele[10] = "G@ABCDEFGH";
 	int row, column, pixels;
-	
+
 	PrivateData *p = (PrivateData *) drvthis->private_data;
-	
+
 
 	if (n<0 && n>15) {
 		debug(RPT_DEBUG, "only characters 0-15 can be changed.\n");
 		return;
 	}
-	
+
 	if (!dat) {
 		debug(RPT_DEBUG, "no character data\n");
 		return;
@@ -493,7 +521,7 @@ MODULE_EXPORT void pyramid_set_char (Driver *drvthis, int n, char *dat)
 
 	// which character?
 	tele[1]=n+0x40;
-	
+
 	for (row = 0; row < p->cellheight; row++) {
 		pixels=0; 
 		for (column = 0; column < p->cellwidth; column++) {
@@ -502,7 +530,7 @@ MODULE_EXPORT void pyramid_set_char (Driver *drvthis, int n, char *dat)
 		}
 		pixels |= 0x40; // pixel information is transferred with
 				// an offset of 40h
-		
+
 		tele[row+2]=pixels;
 	}
         real_send_tele(p, tele, 10);
@@ -684,6 +712,65 @@ pyramid_init_hbar (Driver *drvthis)
 	}
 }
 
+static void
+pyramid_init_custom1 (Driver *drvthis)
+{
+	PrivateData *p = (PrivateData *) drvthis->private_data;
+	char a[] = {
+		0, 0, 0, 0, 0,
+		0, 0, 0, 0, 0,
+		0, 0, 0, 0, 0,
+		0, 1, 1, 1, 1,
+		0, 1, 1, 1, 1,
+		0, 1, 1, 1, 1,
+		0, 1, 1, 1, 1,
+		0, 1, 1, 1, 1,
+	};
+
+	char b[] = {
+		0, 0, 0, 0, 0,
+		0, 0, 0, 0, 0,
+		0, 0, 0, 0, 0,
+		1, 1, 1, 1, 1,
+		1, 1, 1, 1, 0,
+		1, 1, 1, 0, 0,
+		1, 1, 0, 0, 0,
+		1, 0, 0, 0, 0,
+	};
+
+	char c[] = {
+		0, 1, 1, 1, 1,
+		0, 1, 1, 1, 1,
+		0, 1, 1, 1, 1,
+		0, 1, 1, 1, 1,
+		0, 1, 1, 1, 1,
+		0, 0, 0, 0, 0,
+		0, 0, 0, 0, 0,
+		0, 0, 0, 0, 0,
+	};
+
+	char d[] = {
+		1, 0, 0, 0, 0,
+		1, 1, 0, 0, 0,
+		1, 1, 1, 0, 0,
+		1, 1, 1, 1, 0,
+		1, 1, 1, 1, 1,
+		0, 0, 0, 0, 0,
+		0, 0, 0, 0, 0,
+		0, 0, 0, 0, 0,
+	};
+
+	if (p->custom != custom1) {
+		pyramid_set_char (drvthis, 1, a);
+		pyramid_set_char (drvthis, 2, b);
+		pyramid_set_char (drvthis, 3, c);
+		pyramid_set_char (drvthis, 4, d);
+		p->custom = custom1;
+	}
+}
+
+
+
 // Draws a vertical bar...
 
 MODULE_EXPORT void
@@ -712,7 +799,7 @@ pyramid_hbar (Driver *drvthis, int x, int y, int len, int promille, int options)
 MODULE_EXPORT int
 pyramid_icon (Driver *drvthis, int x, int y, int icon)
 {
-	char icons[3][5 * 8] = {
+	char icons[8][5 * 8] = {
 		{
 		 1, 1, 1, 1, 1,			  // Empty Heart
 		 1, 0, 1, 0, 1,
@@ -735,6 +822,61 @@ pyramid_icon (Driver *drvthis, int x, int y, int icon)
 		 1, 1, 1, 1, 1,
 		 },
 
+		{
+                 0, 0, 1, 0, 0, 		  // Arrow up 
+                 0, 1, 1, 1, 0,
+                 1, 0, 1, 0, 1,
+                 0, 0, 1, 0, 0,
+                 0, 0, 1, 0, 0,
+                 0, 0, 1, 0, 0,
+                 0, 0, 1, 0, 0,
+                 0, 0, 0, 0, 0,
+                 },
+
+                {
+                 0, 0, 1, 0, 0, 		  // Arrow Down
+                 0, 0, 1, 0, 0,
+                 0, 0, 1, 0, 0,
+                 0, 0, 1, 0, 0,
+                 1, 0, 1, 0, 1,
+                 0, 1, 1, 1, 0,
+                 0, 0, 1, 0, 0,
+                 0, 0, 0, 0, 0,
+                 },
+
+                {
+                 0, 0, 0, 0, 0,			  // Checkbox off 
+                 0, 0, 0, 0, 0,
+                 1, 1, 1, 1, 1,
+                 1, 0, 0, 0, 1,
+                 1, 0, 0, 0, 1,
+                 1, 0, 0, 0, 1,
+                 1, 1, 1, 1, 1,
+                 0, 0, 0, 0, 0,
+                 },
+
+                {
+                 0, 0, 1, 0, 0, 		  // Checkbox on
+                 0, 0, 1, 0, 0,
+                 1, 1, 1, 0, 1,
+                 1, 0, 1, 1, 0,
+                 1, 0, 1, 0, 1,
+                 1, 0, 0, 0, 1,
+                 1, 1, 1, 1, 1,
+                 0, 0, 0, 0, 0,
+                 },
+
+                {
+                 0, 0, 0, 0, 0,			  // Checkbox gray 
+                 0, 0, 0, 0, 0,
+                 1, 1, 1, 1, 1,
+                 1, 0, 1, 0, 1,
+                 1, 1, 0, 1, 1,
+                 1, 0, 1, 0, 1,
+                 1, 1, 1, 1, 1,
+                 0, 0, 0, 0, 0,
+                 },
+
 		{
 		 0, 0, 0, 0, 0,			  // Ellipsis
 		 0, 0, 0, 0, 0,
@@ -745,11 +887,10 @@ pyramid_icon (Driver *drvthis, int x, int y, int icon)
 		 0, 0, 0, 0, 0,
 		 1, 0, 1, 0, 1,
 		 },
-
 	};
 
-#if 0
 	PrivateData *p = (PrivateData *) drvthis->private_data;
+#if 0
 
 	// notify the others that we messed up their character set.
 	// Unused for heartbeats as we should always leave that icon alone.
@@ -766,16 +907,56 @@ pyramid_icon (Driver *drvthis, int x, int y, int icon)
 			pyramid_chr( drvthis, x, y, 255 );
 			break;
 
-		case ICON_HEART_FILLED:
+		case ICON_HEART_OPEN:
 			pyramid_set_char( drvthis, 0, icons[0] );
 			pyramid_chr( drvthis, x, y, 0 );
 			break;
 
-		case ICON_HEART_OPEN:
+		case ICON_HEART_FILLED:
 			pyramid_set_char( drvthis, 0, icons[1] );
 			pyramid_chr( drvthis, x, y, 0 );
 			break;
 
+		case ICON_ARROW_UP:
+			pyramid_set_char( drvthis, 2, icons[2] );
+			pyramid_chr( drvthis, x, y, 2 );
+			p->custom = icon;
+			break;
+
+		case ICON_ARROW_DOWN:
+			pyramid_set_char( drvthis, 3, icons[3] );
+			pyramid_chr( drvthis, x, y, 3 );
+			p->custom = icon;
+			break;
+
+		case ICON_ARROW_LEFT:
+			pyramid_chr( drvthis, x, y, '\177' );
+			break;
+
+		case ICON_ARROW_RIGHT:
+			pyramid_chr( drvthis, x, y, '\176' );
+			break;
+
+		case ICON_CHECKBOX_ON:
+			pyramid_set_char( drvthis, 10, icons[4] );
+			pyramid_chr( drvthis, x, y, 10 );
+			break;
+
+		case ICON_CHECKBOX_OFF:
+			pyramid_set_char( drvthis, 11, icons[5] );
+			pyramid_chr( drvthis, x, y, 11 );
+			break;
+
+		case ICON_CHECKBOX_GRAY:
+			pyramid_set_char( drvthis, 12, icons[6] );
+			pyramid_chr( drvthis, x, y, 12 );
+			break;
+
+		case ICON_ELLIPSIS:
+			pyramid_set_char( drvthis, 13, icons[7] );
+			pyramid_chr( drvthis, x, y, 13 );
+			break;
+
 		default:
 			printf("x=%d, y=%d, icon=%x\n", x,y,icon);
 			return -1;
@@ -797,6 +978,20 @@ pyramid_cursor (Driver *drvthis, int x, int y, int state)
 
     p->C_x = x;
     p->C_y = y;
+    switch (state) {
+    case CURSOR_OFF:
+	state=0;
+	break;
+    case CURSOR_DEFAULT_ON:
+	state=3;
+	break;
+    case CURSOR_UNDER:
+	state=1;
+	break;
+    case CURSOR_BLOCK:
+	state=2;
+	break;
+    }
     p->C_state = state;
 };
 
@@ -824,8 +1019,12 @@ pyramid_output (Driver *drvthis, int state)
 
     for (i = 0; i < 7; i++) 
         p->led[i] = state & (1 << i);
-    
+
     set_leds(p);
+
+    if(state & (1 << 8)) {
+	    pyramid_init_custom1(drvthis);
+    }
 };
 
 /* Key functions */
@@ -844,7 +1043,7 @@ pyramid_get_key (Driver *drvthis)
      * and as long as we got ACKs, we ignore them. 
      * (eat up all pending ACKs)
      */
-    
+
     while (1) {
         retval = read_tele(p, buffer);
         if ((retval == False) || (buffer[0] != 'Q')) break;
@@ -892,7 +1091,38 @@ pyramid_get_key (Driver *drvthis)
     if (strcmp(p->last_key_pressed, "K1000") == 0) /* last from left */
         return "Escape";
 
-    return NULL;
+#ifdef PYRAMID_DECODE_COMBINED_KEYPRESSES
+    /* Do we really want to type that much */
+    if (strcmp(p->last_key_pressed, "K0012") == 0) /* A+B */
+        return "Up+Down";
+    if (strcmp(p->last_key_pressed, "K0021") == 0) /* B+A */
+        return "Down+Up";
+
+    if (strcmp(p->last_key_pressed, "K0102") == 0) /* A+C */
+        return "Up+Enter";
+    if (strcmp(p->last_key_pressed, "K0201") == 0) /* C+A */
+        return "Enter+Up";
+    if (strcmp(p->last_key_pressed, "K1002") == 0) /* A+D */
+        return "Up+Escape";
+    if (strcmp(p->last_key_pressed, "K2001") == 0) /* D+A */
+        return "Escape+Up";
+
+    if (strcmp(p->last_key_pressed, "K0120") == 0) /* B+C */
+        return "Down+Enter";
+    if (strcmp(p->last_key_pressed, "K0210") == 0) /* C+B */
+        return "Enter+Down";
+    if (strcmp(p->last_key_pressed, "K1020") == 0) /* B+D */
+        return "Down+Escape";
+    if (strcmp(p->last_key_pressed, "K2010") == 0) /* D+B */
+        return "Escape+Down";
+
+    if (strcmp(p->last_key_pressed, "K0012") == 0) /* C+D */
+        return "Enter+Escape";
+    if (strcmp(p->last_key_pressed, "K0021") == 0) /* D+C */
+        return "Escape+Enter";
+#endif
+
+    return NULL; // Ignore combined key events
 };
 
 
