@@ -301,7 +301,7 @@ sed1520_flush (Driver *drvthis)
 // upper-left is (1,1), and the lower right should be (20,4).
 //
 MODULE_EXPORT void
-sed1520_string (Driver *drvthis, int x, int y, char string[])
+sed1520_string (Driver *drvthis, int x, int y, const char string[])
 {
     PrivateData *p = drvthis->private_data;
     int i;
