@@ -1,5 +1,5 @@
 /*
- * Base driver module for Toshiba T6963 based LCD displays. ver 1.2
+ * Base driver module for Toshiba T6963 based LCD displays. ver 2.0
  *
  * Parts of this file are based on the kernel driver by Alexander Frink <Alexander.Frink@Uni-Mainz.DE>
  *
@@ -52,13 +52,21 @@ unsigned char fontdata_6x8[FONTDATAMAX] = {
 0,0,0,0,0,0,
 /* num: 4 */
 0,0,0,0,0,0,
-0,0,0,1,0,0,
+0,0,0,0,0,0,
+0,0,1,0,1,0,
 0,0,1,1,1,0,
-0,1,1,1,1,1,
-0,1,1,1,1,1,
 0,0,1,1,1,0,
 0,0,0,1,0,0,
 0,0,0,0,0,0,
+0,0,0,0,0,0,
+/*0,0,0,0,0,0,
+0,0,1,0,1,0,
+0,1,0,1,0,1,
+0,1,0,0,0,1,
+0,1,0,0,0,1,
+0,0,1,0,1,0,
+0,0,0,1,0,0,
+0,0,0,0,0,0,*/
 /* num: 5 */
 0,0,0,1,0,0,
 0,0,1,1,1,0,
@@ -1995,23 +2003,23 @@ unsigned char fontdata_6x8[FONTDATAMAX] = {
 1,1,1,1,1,1,
 1,1,1,1,1,1,
 /* num: 220 */
-1,1,1,1,1,0,
-1,1,1,1,1,0,
-1,1,1,1,1,0,
-1,1,1,1,1,0,
-1,1,1,1,1,0,
-1,1,1,1,1,0,
-1,1,1,1,1,0,
-1,1,1,1,1,0,
+1,0,0,0,0,0,
+1,0,0,0,0,0,
+1,0,0,0,0,0,
+1,0,0,0,0,0,
+1,0,0,0,0,0,
+1,0,0,0,0,0,
+1,0,0,0,0,0,
+1,0,0,0,0,0,
 /* num: 221 */
-1,1,1,1,0,0,
-1,1,1,1,0,0,
-1,1,1,1,0,0,
-1,1,1,1,0,0,
-1,1,1,1,0,0,
-1,1,1,1,0,0,
-1,1,1,1,0,0,
-1,1,1,1,0,0,
+1,1,0,0,0,0,
+1,1,0,0,0,0,
+1,1,0,0,0,0,
+1,1,0,0,0,0,
+1,1,0,0,0,0,
+1,1,0,0,0,0,
+1,1,0,0,0,0,
+1,1,0,0,0,0,
 /* num: 222 */
 1,1,1,0,0,0,
 1,1,1,0,0,0,
@@ -2022,23 +2030,23 @@ unsigned char fontdata_6x8[FONTDATAMAX] = {
 1,1,1,0,0,0,
 1,1,1,0,0,0,
 /* num: 223 */
-1,1,0,0,0,0,
-1,1,0,0,0,0,
-1,1,0,0,0,0,
-1,1,0,0,0,0,
-1,1,0,0,0,0,
-1,1,0,0,0,0,
-1,1,0,0,0,0,
-1,1,0,0,0,0,
+1,1,1,1,0,0,
+1,1,1,1,0,0,
+1,1,1,1,0,0,
+1,1,1,1,0,0,
+1,1,1,1,0,0,
+1,1,1,1,0,0,
+1,1,1,1,0,0,
+1,1,1,1,0,0,
 /* num: 224 */
-1,0,0,0,0,0,
-1,0,0,0,0,0,
-1,0,0,0,0,0,
-1,0,0,0,0,0,
-1,0,0,0,0,0,
-1,0,0,0,0,0,
-1,0,0,0,0,0,
-1,0,0,0,0,0,
+1,1,1,1,1,0,
+1,1,1,1,1,0,
+1,1,1,1,1,0,
+1,1,1,1,1,0,
+1,1,1,1,1,0,
+1,1,1,1,1,0,
+1,1,1,1,1,0,
+1,1,1,1,1,0,
 /* num: 225 */
 0,0,0,0,0,0,
 0,1,1,1,0,0,
