@@ -261,7 +261,7 @@ sli_clear (Driver *drvthis)
 // upper-left is (1,1), and the lower right should be (20,4).
 //
 MODULE_EXPORT void
-sli_string (Driver *drvthis, int x, int y, char string[])
+sli_string (Driver *drvthis, int x, int y, const char string[])
 {
 	PrivateData *p = drvthis->private_data;
 	int i;
