@@ -17,7 +17,7 @@ MODULE_EXPORT int  sli_cellwidth (Driver *drvthis);
 MODULE_EXPORT int  sli_cellheight (Driver *drvthis);
 MODULE_EXPORT void sli_clear (Driver *drvthis);
 MODULE_EXPORT void sli_flush (Driver *drvthis);
-MODULE_EXPORT void sli_string (Driver *drvthis, int x, int y, char *string);
+MODULE_EXPORT void sli_string (Driver *drvthis, int x, int y, const char string[]);
 MODULE_EXPORT void sli_chr (Driver *drvthis, int x, int y, char c);
 
 MODULE_EXPORT void sli_vbar (Driver *drvthis, int x, int y, int len, int promille, int options);
