@@ -13,6 +13,6 @@
 #define PARSE_H
 
 // This should be pretty self-explanatory...
-int parse_all_client_messages ();
+int parse_all_client_messages(void);
 
 #endif
