@@ -398,10 +398,10 @@ LL_DeleteNode (LinkedList * list)
 	if (list->current == &list->tail)
 		return NULL;
 
-#ifdef DEBUG
+/*
 	printf ("LL_DeleteNode: Before...\n");
 	LL_dprint (list);
-#endif
+*/
 
 	next = list->current->next;
 	prev = list->current->prev;
@@ -423,10 +423,10 @@ LL_DeleteNode (LinkedList * list)
 
 	list->current = next;
 
-#ifdef DEBUG
+/*
 	printf ("LL_DeleteNode: After...\n");
 	LL_dprint (list);
-#endif
+*/
 
 	return data;
 }
@@ -743,6 +743,30 @@ LL_Find (LinkedList * list, int compare (void *, void *), void *value)
 	return NULL;
 }
 
+//////////////////////////////////////////////////////////////////////
+// Array like...
+// Goes to the nth list item, and returns the
+// data found there.
+//
+void *
+LL_GetByIndex (LinkedList * list, int index)
+{
+	LL_node *node;
+	int num = 0;
+
+	if (!list)
+		return NULL;
+	if (index<0)
+		return NULL;
+
+	for (node = list->head.next; node != &list->tail; node = node->next) {
+		if (num == index)
+			return node->data;
+		num ++;
+	}
+	return NULL; // got past the end
+}
+
 //////////////////////////////////////////////////////////////////////
 // Sorts the list, then rewinds it...
 //
